# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Azerbaijani(Language):
    """For transcribing Azerbaijani."""

    __iso639__ = {1: 'az', 2: 'aze', 3: 'aze'}
    __tmp__ = ',;'

    vowels = 'aAeIioOuU'
    cs = 'bcCdfgGhjklmnNpqrsStvxz'
    vl = 'CfhkKpsStx'
    notation = Notation([
        ('-', '/'),
        (u'ə', 'A'),
        (u'ç', 'C'),
        (u'ğ', 'G'),
        (u'ı', 'I'),
        (u'ö', 'O'),
        (u'ş', 'S'),
        (u'ü', 'U'),
        ('^y{@}', 'Y'),
        ('iyy', 'iy'),
        ('yy', 'iy'),
        ('{@}y{@}', 'Y'),
        ('iy', 'i'),
        ('y', 'i'),
        ('rl', 'l'),
        ('{p|t|k}h', None),
        ('w', 'v'),
        ('bb', 'b'),
        ('cc', 'c'),
        ('CC', 'C'),
        ('dd', 'd'),
        ('dc', 'c'),
        ('ff', 'f'),
        ('gg', 'g'),
        ('GG', 'G'),
        ('hh', 'h'),
        ('jj', 'j'),
        ('kk', 'k'),
        ('ll', 'l'),
        ('mm', 'm,m'),
        ('nn', 'n,n'),
        ('pp', 'p'),
        ('qq', 'q'),
        ('rr', 'r'),
        ('ss', 's'),
        ('SS', 'S'),
        ('tt', 't'),
        ('tC', 'C'),
        ('vv', 'v'),
        ('xx', 'x'),
        ('zz', 'z'),
        ('aa', 'a'),
        ('AA', 'A'),
        ('ee', 'e'),
        ('ii', 'i'),
        ('II', 'I'),
        ('oo', 'o'),
        ('OO', 'O'),
        ('uu', 'u'),
        ('UU', 'U'),
        ('b{<vl>}', 'p'),
        ('b$', 'p'),
        ('c{<vl>}', 'C'),
        ('c$', 'C'),
        ('d{<vl>}', 't'),
        ('d$', 't'),
        ('g{<vl>}', 'k'),
        ('g$', 'k'),
        ('G{<vl>}', 'x'),
        ('G$', 'x'),
        ('j{<vl>}', 'S'),
        ('j$', 'S'),
        ('q{<vl>}', 'Q'),
        ('q$', 'Q'),
        ('v{<vl>}', 'f'),
        ('v$', 'f'),
        ('z{<vl>}', 's'),
        ('z$', 's'),
        ('{@}k{<vl>}', 'k,'),
        ('{@}p{<vl>}', 'p,'),
        ('{@}Q{<vl>}', 'k,'),
        ('c{<cs>}', 'ci'),
        ('c$', 'ci'),
        ('C{<cs>}', 'Ci'),
        ('C$', 'Ci'),
        ('j{<cs>}', 'ju'),
        ('j$', 'ju'),
        ('S{@}', 'sY'),
        ('S', 'sYu'),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('n{G|q|Q|x}', 'N'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('b', Choseong(B)),
        ('c', Choseong(J)),
        ('C', Choseong(C)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(G)),
        ('G', Choseong(G)),
        ('h', Choseong(H)),
        ('j', Choseong(J)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('q', Choseong(G)),
        ('Q', Choseong(K)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t', Choseong(T)),
        ('v', Choseong(B)),
        ('x', Choseong(H)),
        ('z', Choseong(J)),
        ('Ya', Jungseong(YA)),
        ('YA', Jungseong(YE)),
        ('Ye', Jungseong(YE)),
        ('YI', Jungseong(I), Jungseong(EU)),
        ('Yi', Jungseong(I)),
        ('Yo', Jungseong(YO)),
        ('YO', Jungseong(OE)),
        ('Yu', Jungseong(YU)),
        ('YU', Jungseong(WI)),
        ('a', Jungseong(A)),
        ('A', Jungseong(E)),
        ('e', Jungseong(E)),
        ('I', Jungseong(EU)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('O', Jungseong(OE)),
        ('u', Jungseong(U)),
        ('U', Jungseong(WI)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ə': u'ə', u'Ç': u'ç', u'Ğ': u'ğ', u'I': u'ı', u'İ': u'i',
            u'Ö': u'ö', u'Ş': u'ş', u'Ü': u'ü', u'А': u'a', u'а': u'a',
            u'Ә': u'ə', u'ә': u'ə', u'Б': u'b', u'б': u'b', u'Ҹ': u'c',
            u'ҹ': u'c', u'Ч': u'ç', u'ч': u'ç', u'Д': u'd', u'д': u'd',
            u'Е': u'e', u'е': u'e', u'Ф': u'f', u'ф': u'f', u'Ҝ': u'g',
            u'ҝ': u'g', u'Ғ': u'ğ', u'ғ': u'ğ', u'Һ': u'h', u'һ': u'h',
            u'Х': u'x', u'х': u'x', u'Ы': u'ı', u'ы': u'ı', u'И': u'i',
            u'и': u'i', u'Ж': u'j', u'ж': u'j', u'К': u'k', u'к': u'k',
            u'Г': u'q', u'г': u'q', u'Л': u'l', u'л': u'l', u'М': u'm',
            u'м': u'm', u'Н': u'n', u'н': u'n', u'О': u'o', u'о': u'o',
            u'Ө': u'ö', u'ө': u'ö', u'П': u'p', u'п': u'p', u'Р': u'r',
            u'р': u'r', u'С': u's', u'с': u's', u'Ш': u'ş', u'ш': u'ş',
            u'Т': u't', u'т': u't', u'У': u'u', u'у': u'u', u'Ү': u'ü',
            u'ү': u'ü', u'В': u'v', u'в': u'v', u'Ј': u'y', u'ј': u'y',
            u'З': u'z', u'з': u'z'
        })


__lang__ = Azerbaijani
