# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Belarusian(Language):
    """For transcribing Belarusian."""

    __iso639__ = {1: 'be', 2: 'bel', 3: 'bel'}
    __tmp__ = ',;'

    vowels = u'аеёійоуыьэюя'
    cs = u'бвгґджзклмнпрстфхцчш'
    vl = u'кпстфхцчш'
    notation = Notation([
        (u'{ж|з|ц|ч|ш}ь{@}', None),
        (u'ьа', u'я'),
        (u'йа', u'я'),
        (u'ьі', u'і'),
        (u'йі', u'і'),
        (u'ьо', u'ё'),
        (u'йо', u'ё'),
        (u'ьу', u'ю'),
        (u'йу', u'ю'),
        (u'ьы', u'ы'),
        (u'йы', u'ы'),
        (u'ьэ', u'е'),
        (u'йэ', u'е'),
        (u'^ль', u'лі'),
        (u'^мь', u'мі'),
        (u'^нь', u'ні'),
        (u'{л|м|н}ь{е|ю|я|ё}', u'і'),
        (u'{л|м|н}ьй', u'й'),
        (u'{л|м|н}ь$', None),
        (u'{л|м|н}ь{<cs>}', None),
        (u'{<cs>}\'{е|й|ю|я|ё}', u'і'),
        (u'бб', u'б'),
        (u'гг', u'г'),
        (u'дд', u'д'),
        (u'дц', u'ц'),
        (u'дч', u'ч'),
        (u'жж', u'ж'),
        (u'зз', u'з'),
        (u'кк', u'к'),
        (u'лл', u'л'),
        (u'{@}мм{@}', u'м,м'),
        (u'мм', u'м'),
        (u'{@}нн{@}', u'н,н'),
        (u'нн', u'н'),
        (u'пп', u'п'),
        (u'рр', u'р'),
        (u'сс', u'с'),
        (u'тт', u'т'),
        (u'тц', u'ц'),
        (u'тч', u'ч'),
        (u'фф', u'ф'),
        (u'хх', u'х'),
        (u'цц', u'ц'),
        (u'чч', u'ч'),
        (u'шш', u'ш'),
        (u'шч', u'ш'),
        (u'{з|с|ц}ь', None),
        (u'ій', u'і'),
        (u'{@}ь', None),
        (u'дс$', u'ц'),
        (u'дс{<cs>}', u'ц'),
        (u'тс', u'ц'),
        (u'дз', u'з'),
        (u'тс', u'ц'),
        (u'дз', u'з'),
        (u'тз', u'з'),
        (u'нкт', u'Nт'),
        (u'^в{<cs>}', u'у'),
        (u'{@}в{<cs>}', u'у'),
        (u'{@}в$', u'у'),
        (u'б{<vl>}', u'п'),
        (u'б$', u'п'),
        (u'в{<vl>}', u'ф'),
        (u'в$', u'ф'),
        (u'г{<vl>}', u'к'),
        (u'г$', u'к'),
        (u'д{<vl>}', u'т'),
        (u'д$', u'т'),
        (u'ж{<vl>}', u'ш'),
        (u'ж$', u'ш'),
        (u'з{<vl>}', u'с'),
        (u'з$', u'с'),
        (u'{@}к{<vl>}', u'к,'),
        (u'{@}п{<vl>}', u'п,'),
        (u'{ж|з|ц|ч}O', u'о'),
        (u'{ж|з|ц|ч}ю', u'у'),
        (u'{ж|з|ц|ч}я', u'а'),
        (u'{<cs>}е', u'э'),
        (u'ша', u'ся'),
        (u'шэ', u'се'),
        (u'шо', u'сё'),
        (u'шу', u'сю'),
        (u'ш{і|й|ы|ь}', u'с'),
        (u'ш$', u'сі'),
        (u'ш', u'сю'),
        (u'дж{@}', u'з'),
        (u'дж', u'зі'),
        (u'ж{@}', u'з'),
        (u'ж', u'зу'),
        (u'ч{@}', u'ц'),
        (u'ч', u'чі'),
        (u'^л', u'л;'),
        (u'^м', u'м;'),
        (u'^н', u'н;'),
        (u'л$', u'л,'),
        (u'м$', u'м,'),
        (u'н$', u'н,'),
        (u'л{@|м,|н,|N}', u'л;'),
        (u'м{@|л}', u'м;'),
        (u'н{@|л}', u'н;'),
        (u'л', u'л,'),
        (u'м', u'м,'),
        (u'н', u'н,'),
        (u',,', u','),
        (u',;', None),
        (u',л,', u'л,'),
        (u',м,', u'м,'),
        (u',н,', u'н,'),
        (u'л{м;|н;}', u'л,'),
        (u';|-', None),
        (u'б', Choseong(B)),
        (u'в', Choseong(B)),
        (u'г', Choseong(H)),
        (u'ґ', Choseong(G)),
        (u'д', Choseong(D)),
        (u'ж', Choseong(J)),
        (u'з', Choseong(J)),
        (u'ж', Choseong(J)),
        (u'к,', Jongseong(G)),
        (u'к', Choseong(K)),
        (u'^л', Choseong(L)),
        (u'{,}л', Choseong(L)),
        (u'л,', Jongseong(L)),
        (u'л', Jongseong(L), Choseong(L)),
        (u'м,', Jongseong(M)),
        (u'м', Choseong(M)),
        (u'н,', Jongseong(N)),
        (u'н', Choseong(N)),
        (u'N', Jongseong(NG)),
        (u'п,', Jongseong(B)),
        (u'п', Choseong(P)),
        (u'р', Choseong(L)),
        (u'с', Choseong(S)),
        (u'т', Choseong(T)),
        (u'ф', Choseong(P)),
        (u'х', Choseong(H)),
        (u'ц', Choseong(C)),
        (u'ч', Choseong(C)),
        (u'а', Jungseong(A)),
        (u'е', Jungseong(YE)),
        (u'ё', Jungseong(YO)),
        (u'і', Jungseong(I)),
        (u'й', Jungseong(I)),
        (u'о', Jungseong(O)),
        (u'у', Jungseong(U)),
        (u'ў', Jungseong(U)),
        (u'ы', Jungseong(I)),
        (u'ь', Jungseong(I)),
        (u'э', Jungseong(E)),
        (u'ю', Jungseong(YU)),
        (u'я', Jungseong(YA))
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'А': u'а', u'Б': u'б', u'В': u'в', u'Г': u'г', u'Ґ': u'ґ',
            u'Д': u'д', u'Е': u'е', u'Ё': u'ё', u'Ж': u'ж', u'З': u'з',
            u'І': u'і', u'Й': u'й', u'К': u'к', u'Л': u'л', u'М': u'м',
            u'Н': u'н', u'О': u'о', u'П': u'п', u'Р': u'р', u'С': u'с',
            u'Т': u'т', u'У': u'у', u'Ў': u'ў', u'Ф': u'ф', u'Х': u'х',
            u'Ц': u'ц', u'Ч': u'ч', u'Ш': u'ш', u'Ы': u'ы', u'Ь': u'ь',
            u'Э': u'э', u'Ю': u'ю', u'Я': u'я'
        })


__lang__ = Belarusian
