# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Catalan(Language):
    """For transcribing Catalan."""

    __iso639__ = {1: 'ca', 2: 'cat', 3: 'cat'}
    __tmp__ = ',;'

    vowels = u'aeiouü'
    cs = 'bcCdDfghklmnNprsStTvwxzZ'
    ob = 'bcCdDfgkpqsStTxzZ'
    vo = 'bdDglmnNrvwzZ'
    vl = 'cCfkpqsStTx'
    notation = Notation([
        ('felix$', 'felics'),
        ('helix$', 'helics'),
        ('^fix', 'fics'),
        ('^aux{@}', 'augz'),
        ('^ex{@}', 'egz'),
        ('{@}s{@}', 'z'),
        ('{~s}s{<vo>}', 'z'),
        (u'ç', 's'),
        ('c{e|i}', 's'),
        ('g{e|i}', 'j'),
        (u'{g|q}ü{e|i}', 'W'),
        ('{g|q}u{e|i}', None),
        (u'ü', 'u'),
        ('{g|q}ua', 'Wa'),
        ('k', 'c'),
        ('q', 'c'),
        (u'·', ','),
        ('{@}ig$', 'C'),
        ('{@}igs$', 'Cs'),
        ('{@}ix', 'S'),
        ('ix{@}', 'iS'),
        ('ix$', 'iS'),
        ('{@}ux', 'uS'),
        ('ll', 'L'),
        ('ny{@}', 'nY'),
        ('{~<cs>}y{@}', 'Y'),
        ('y', 'i'),
        ('dj', 'D'),
        ('tj', 'D'),
        ('tx', 'C'),
        ('dz', 'Z'),
        ('tz', 'Z'),
        ('{@}ds{@}', 't,s'),
        ('{@}ts{@}', 't,s'),
        ('{l|n}d{~@|l|r}', None),
        ('{l|n}t{~@|l|r}', None),
        ('mb{~@|l|r}', 'm'),
        ('mp{~@|l|r}', 'm'),
        ('nc{@|l|r|W}', 'N,c'),
        ('nc', 'N,'),
        ('ng{@|l|r|W}', 'N,g'),
        ('ng', 'N,'),
        ('L{@}', 'lY'),
        ('L', 'l'),
        ('rds', 'rs'),
        ('rts', 'rs'),
        ('ds', 'T'),
        ('ts', 'T'),
        ('{@}x', 'cs'),
        ('x', 'S'),
        ('w', 'v'),
        ('h', None),
        ('b$', 'p'),
        ('b{<vl>}', 'p'),
        ('d$', 't'),
        ('d{<vl>}', 't'),
        ('ds{@}', 't,s'),
        ('D{<vl>}', 'C'),
        ('D$', 'C'),
        ('D', 'z'),
        ('g$', 'k'),
        ('g{<vl>}', 'k'),
        ('v{<vl>}', 'f'),
        ('v$', 'f'),
        ('z{<vl>}', 's'),
        ('z$', 's'),
        ('Z{<vl>}', 'T'),
        ('Z$', 'T'),
        ('{@}c{<ob>}', 'c,'),
        ('{@}p{<ob>}', 'p,'),
        ('{@}t{<ob>}', 't,'),
        ('bb', 'b'),
        ('bv', 'b'),
        ('cc', 'c'),
        ('dd', 'd'),
        ('ff', 'f'),
        ('gg', 'g'),
        ('ll', 'l'),
        ('mm', 'm'),
        ('nn', 'n'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('tt', 't'),
        ('zz', 'z'),
        ('v', 'b'),
        ('tS', 'C'),
        ('C{@}', 'T'),
        ('C', 'Ti'),
        ('S{@}', 'sY'),
        ('S$', 'si'),
        ('S', 'sYu'),
        ('Z', 'z'),
        ('y', 'i'),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|Y|m,|n,}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@|Y}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('b', Choseong(B)),
        ('c,', Jongseong(G)),
        ('c', Choseong(K)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(G)),
        ('j', Choseong(J)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t,', Jongseong(S)),
        ('t', Choseong(T)),
        ('T', Choseong(C)),
        ('z', Choseong(J)),
        ('Ya', Jungseong(YA)),
        ('Ye', Jungseong(YE)),
        ('Yi', Jungseong(I)),
        ('Yo', Jungseong(YO)),
        ('Yu', Jungseong(YU)),
        ('Wa', Jungseong(WA)),
        ('We', Jungseong(WE)),
        ('Wi', Jungseong(WI)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('u', Jungseong(U)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {u'Ç': u'ç', u'Ü': u'ü', u'•': u'·'})


__lang__ = Catalan
