# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Estonian(Language):
    """For transcribing Estonian."""

    __iso639__ = {1: 'et', 2: 'est', 3: 'est'}
    __tmp__ = ',;%'

    vowels = 'aAeEioOuUy'
    ob = 'bdfgkpstT'
    notation = Notation([
        # Convention: E = õ, A = ä, O = ö, U = ü
        ('-', '/'),
        (u'õ', 'E'),
        (u'ä', 'A'),
        (u'ö', 'O'),
        (u'ü', 'U'),
        (u'š', 'S'),
        (u'ž', 'Z'),
        ('w', 'v'),
        ('xx', 'x'),
        ('x', 'ks'),
        ('z', 's'),
        ('ds', 'T'),
        ('ts', 'T'),
        ('dS', 'C'),
        ('tS', 'C'),
        ('dZ{@}', 'z'),
        ('dZ', 'zi'),
        ('Z{@}', 'z'),
        ('Z', 'zu'),
        ('C{@}', 'T'),
        ('C', 'Ti'),
        ('SO', 'SE'),
        ('S{@}', 'sJ'),
        ('S$', 'si'),
        ('S', 'sJu'),
        ('c{e|i|y}', 's'),
        ('c', 'k'),
        ('q', 'k'),
        ('ng', 'N'),
        ('nk', 'Nk'),
        ('y{@}', 'J'),
        ('{@}y', 'i'),
        ('y', 'U'),
        ('^j{@}', 'J'),
        ('{@|-}j{@}', 'J'),
        ('{h|s}j', '%J'),
        ('j', 'i'),
        ('aa', 'a'),
        ('AA', 'A'),
        ('bb', 'b'),
        ('dd', 'd'),
        ('ee', 'e'),
        ('EE', 'E'),
        ('ff', 'f'),
        ('gg', 'g'),
        ('hh', 'h'),
        ('ii', 'i'),
        ('jj', 'j'),
        ('kk', 'k'),
        ('ll', 'l'),
        ('{@}mm{@}', 'm,m'),
        ('mm', 'm'),
        ('{@}nn{@}', 'n,n'),
        ('nn', 'n'),
        ('oo', 'o'),
        ('OO', 'O'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('tt', 't'),
        ('uu', 'u'),
        ('UU', 'U'),
        ('vv', 'v'),
        ('yy', 'y'),
        ('zz', 'z'),
        ('{@}b{<ob>}', 'p,'),
        ('{@}g{<ob>}', 'k,'),
        ('{@}k{<ob>}', 'k,'),
        ('{@}p{<ob>}', 'p,'),
        ('{@}t{<ob>}', 't,'),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        ('N', 'N,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        (',N,', 'N,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('b', Choseong(B)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(G)),
        ('h', Choseong(H)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,|-}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t,', Jongseong(S)),
        ('t', Choseong(T)),
        ('T', Choseong(C)),
        ('v', Choseong(B)),
        ('%', Choseong(NG)),
        ('Ja', Jungseong(YA)),
        ('JA', Jungseong(YAE)),
        ('Je', Jungseong(YE)),
        ('JE', Jungseong(YEO)),
        ('Ji', Jungseong(I)),
        ('Jo', Jungseong(YO)),
        ('JO', Jungseong(OE)),
        ('Ju', Jungseong(YU)),
        ('JU', Jungseong(WI)),
        ('a', Jungseong(A)),
        ('A', Jungseong(AE)),
        ('e', Jungseong(E)),
        ('E', Jungseong(EO)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('u', Jungseong(U)),
        ('U', Jungseong(WI)),
        ('O', Jungseong(OE)),
    ])

    def normalize(self, string):
        additional = {u'Š': u'š', u'Ž': u'ž', u'Õ': u'õ', u'Ä': u'ä',
                      u'Ö': u'ö', u'Ü': u'ü'}
        return normalize_roman(string, additional)


__lang__ = Estonian
