# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Icelandic(Language):
    """For transcribing Icelandic."""

    __iso639__ = {1: 'is', 2: 'ice', 3: 'isl'}
    __tmp__ = ',;%'

    vowels = 'aAeEiIoOuUyWXYQ'
    cs = 'bdDfFghHjJklmnNprsStTvZ'
    pl = 'bdgkpt'
    ld = 'AEIOUYWX'

    notation = Notation([
        (u'ð', 'D'),
        (u'þ', 'T'),
        (u'á', 'A'),
        (u'é', 'E'),
        (u'í', 'I'),
        (u'ó', 'O'),
        (u'ú', 'U'),
        (u'æ', 'Y'),
        (u'ö', 'Q'),
        ('^alli$', 'ali'),
        ('^bolla', 'bola'),
        ('^cilla', 'cila'),
        ('^dalla', 'dala'),
        ('^ella', 'ela'),
        ('^elli', 'eli'),
        ('erlend', 'er-lend'),
        ('faDir', 'FaDir'),
        ('fall', 'Fall'),
        ('feD{ur|ra}', 'FeD'),
        ('fell', 'Fell'),
        ('firDi', 'FirDi'),
        ('fjarlYg', 'fjar-lYg'),
        ('foss', 'Foss'),
        ('fOlk', 'FOlk'),
        ('fugl', 'Fugl'),
        ('fylk{i|j}', 'Fylk'),
        ('fQDur', 'FQDur'),
        ('fQll', 'FQll'),
        ('gud{brand|jon|laug|mund|rid|run}', 'guD'),
        ('guD', 'gvuD'),
        ('halldOr', 'hadldOr'),
        ('^halla', 'hala'),
        ('^halli', 'hali'),
        ('^hella', 'hela'),
        ('^helli', 'heli'),
        ('^hilla', 'hila'),
        ('jQkull', '%jQkull'),
        ('^kalla', 'kala'),
        ('^kamilla', 'kamila'),
        ('^kalli', 'kali'),
        ('^malla', 'mala'),
        ('^malli', 'mali'),
        ('^milla', 'mila'),
        ('^nella', 'nela'),
        ('^palli', 'pali'),
        ('^silla', 'sila'),
        ('stefAn', 'steFAn'),
        ('sumarn{Ott|Yt}', 'sumar-n'),
        ('^thor', 'Tor'),
        ('^Tor', 'Tor-'),
        ('^tolla', 'tola'),
        ('varleg', 'var-leg'),
        ('^villi', 'vili'),
        ('nni$', 'n,ni'),
        ('y', 'i'),
        (u'ý', 'I'),
        ('au', 'W'),
        ('ei', 'X'),
        ('c{e|E|i|I}', 's'),
        ('c', 'k'),
        ('qu', 'kv'),
        ('q', 'k'),
        ('w', 'v'),
        ('xx', 'x'),
        ('x', 'ks'),
        ('tss{@}', 'Ss'),
        ('ss', 's'),
        ('ds', 's'),
        ('ds{<cs>}', 'Z'),
        ('ds$', 'Z'),
        ('Ds', 's'),
        ('fn{d|t}', 'm'),
        ('ff', 'F'),
        ('f$', 'v'),
        ('{@|l}f{@}', 'v'),
        ('f', 'F'),
        ('{@}g$', 'H'),
        ('{@}g{s|S|t}', 'k,'),
        ('{a|e|o|u|Q}g{i|I|j}', 'i'),
        ('{@}g{i|I|j}', 'J'),
        ('{g|h|k|s}j', 'J'),
        ('{g|k}Y', 'JY'),
        ('hv', 'kv'),
        ('{@}k{s|S|t}', 'k,'),
        ('ll{d|s|t}', 'l'),
        ('ll', 'dl'),
        ('{@}mm{@}', 'm,m'),
        ('mm', 'm'),
        ('an{g|k}', 'An'),
        ('en{g|k}', 'ein'),
        ('un{g|k}', 'Un'),
        ('Qn{g|k}', 'Qin'),
        ('ng{s|<pl>}', 'N'),
        ('{@}ngl{@}', 'Nl'),
        ('ng', 'Ng'),
        ('{@}nkl{@}', 'Nl'),
        ('nk', 'Nk'),
        ('{<ld>}nn', 'dn'),
        ('{@}nn{@}', 'n,n'),
        ('nn', 'n'),
        ('pp', 'p'),
        ('r{l|n}', 'rd'),
        ('z', 's'),
        ('ts{<cs>}', 'S'),
        ('ts$', 'S'),
        ('^j{@}', 'J'),
        ('{@|%}j{@}', 'J'),
        ('Dj', 'D%J'),
        ('j', 'i'),
        ('A', 'aU'),
        ('I', 'i'),
        ('O', 'o'),
        ('W', 'Qi'),
        ('X', 'ei'),
        ('^E', 'Je'),
        ('{@|h}E', 'Je'),
        ('E', 'ie'),
        ('Y', 'ai'),
        ('', ''),
        ('bb', 'b'),
        ('dd', 'd'),
        ('gg', 'g'),
        ('hh', 'h'),
        ('kk', 'k'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('tt', 't'),
        ('vv', 'v'),
        ('h{@|J|l|n|r}', 'H'),
        ('h', None),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        ('N', 'N,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        (',N,', 'N,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('-', None),
        ('b', Choseong(B)),
        ('d', Choseong(D)),
        ('D', Choseong(D)),
        ('F', Choseong(P)),
        ('g', Choseong(G)),
        ('H', Choseong(H)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('S', Choseong(C)),
        ('t', Choseong(T)),
        ('T', Choseong(S)),
        ('v', Choseong(B)),
        ('Z', Choseong(J)),
        ('%', Choseong(NG)),
        ('Ja', Jungseong(YA)),
        ('Je', Jungseong(YE)),
        ('Ji', Jungseong(I)),
        ('Jo', Jungseong(YO)),
        ('Ju', Jungseong(YU)),
        ('JU', Jungseong(YU)),
        ('JQ', Jungseong(YE)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('u', Jungseong(WI)),
        ('U', Jungseong(U)),
        ('Q', Jungseong(OE)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Á': u'á', u'Ð': u'ð', u'É': u'é', u'Í': u'í', u'Ó': u'ó',
            u'Ú': u'ú', u'Ý': u'ý', u'Þ': u'þ', u'Æ': u'æ', u'Ö': u'ö'
        })


__lang__ = Icelandic
