# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Italian(Language):
    """For transcribing Italian."""

    __iso639__ = {1: 'it', 2: 'ita', 3: 'ita'}
    __tmp__ = ",;"

    vowels = 'aeiou'
    notation = Notation([
        ('\'',            None),
        ('^gli$',         'li'),
        ('^glia$',        'g.lia'),
        ('^glioma$',      'g.lioma'),
        ('^gli{@}',       'li'),
        ('{@}gli',        'li'),
        ('gn{@}',         'nJ'),
        ('gn',            'n'),
        ('gg',            'g'),
        ('gi{a|o|u}',     'G'),
        ('g{e|i}',        'G'),
        ('ss',            's'),
        ('sce',           'sJe'),
        ('sci',           'si'),
        ('cc',            'c'),
        ('ci{a|o|u}',     'z'),
        ('c{e|i}',        'z'),
        ('c',             'k'),
        ('qq',            'q'),
        ('quo',           'kuo'),
        ('qu{a|e|i}',     'kW'),
        ('quy',           'kWi'),
        ('q',             'k'),
        ('xx',            'x'),
        ('x',             'ks'),
        ('tt',            't'),
        ('ts',            'z'),
        ('w',             'v'),
        ('aa',            'a'),
        ('bb',            'b'),
        ('dd',            'd'),
        ('ee',            'e'),
        ('ff',            'f'),
        ('hh',            'h'),
        ('{@}h{@}',       '.'),
        ('h',             None),
        ('ii',            'i'),
        ('jj',            'j'),
        ('^j{@}',         'J'),
        ('{@}j{@}',       'J'),
        ('j',             'i'),
        ('kk',            'k'),
        ('ll',            'l'),
        ('{@}mm{@}',      'm,m'),
        ('mm',            'm'),
        ('{@}nn{@}',      'n,n'),
        ('nn',            'n'),
        ('oo',            'o'),
        ('pp',            'p'),
        ('rr',            'r'),
        ('tt',            't'),
        ('uu',            'u'),
        ('vv',            'v'),
        ('^y{@}',         'J'),
        ('yy',            'y'),
        ('y',             'i'),
        ('zz',            'z'),
        ('{@}k{p|s|t|z}', 'k,'),
        ('{@}p{k|s|t|z}', 'p,'),
        ('^l',            'l;'),
        ('^m',            'm;'),
        ('^n',            'n;'),
        ('l$',            'l,'),
        ('m$',            'm,'),
        ('n$',            'n,'),
        ('l{@|m,|n,}',    'l;'),
        ('{,}l',          'l;'),
        ('m{@}',          'm;'),
        ('n{@|J}',        'n;'),
        ('l',             'l,'),
        ('m',             'm,'),
        ('n',             'n,'),
        (',,',            ','),
        (',;',            None),
        (',l,',           'l,'),
        (',m,',           'm,'),
        (',n,',           'n,'),
        ('l{mn}',         'l,'),
        (';',             None),
        ('b',             Choseong(B)),
        ('d',             Choseong(D)),
        ('f',             Choseong(P)),
        ('g',             Choseong(G)),
        ('G',             Choseong(J)),
        ('k,',            Jongseong(G)),
        ('k',             Choseong(K)),
        ('^l',            Choseong(L)),
        ('{,}l',          Choseong(L)),
        ('l,',            Jongseong(L)),
        ('l',             Jongseong(L), Choseong(L)),
        ('m,',            Jongseong(M)),
        ('m',             Choseong(M)),
        ('n,',            Jongseong(N)),
        ('n',             Choseong(N)),
        ('p,',            Jongseong(B)),
        ('p',             Choseong(P)),
        ('r',             Choseong(L)),
        ('s',             Choseong(S)),
        ('t',             Choseong(T)),
        ('v',             Choseong(B)),
        ('z',             Choseong(C)),
        ('Ja',            Jungseong(YA)),
        ('Je',            Jungseong(YE)),
        ('Ji',            Jungseong(I)),
        ('Jo',            Jungseong(YO)),
        ('Ju',            Jungseong(YU)),
        ('Wa',            Jungseong(WA)),
        ('We',            Jungseong(WE)),
        ('Wi',            Jungseong(WI)),
        ('a',             Jungseong(A)),
        ('e',             Jungseong(E)),
        ('i',             Jungseong(I)),
        ('o',             Jungseong(O)),
        ('u',             Jungseong(U)),
    ])

    def normalize(self, string):
        return normalize_roman(string)


__lang__ = Italian
