# -*- coding: utf-8 -*-
from six import unichr
from six.moves import range

from kss._modules.hangulization.hangulize import *


class Japanese(Language):
    """For transcribing Japanese."""

    __iso639__ = {1: 'ja', 2: 'jpn', 3: 'jpn'}
    __tmp__ = ''.join((chr(x) + chr(x).upper()) \
                      for x in range(ord('a'), ord('z') + 1))

    notation = Notation([
        (u'ア|ァ',    'a'),
        (u'イ|ィ',    'i'),
        (u'ウ|ゥ',    'u'),
        (u'エ|ェ',    'e'),
        (u'オ|ォ',    'o'),
        (u'カ',       'ka'),
        (u'キ',       'ki'),
        (u'ク',       'ku'),
        (u'ケ',       'ke'),
        (u'コ',       'ko'),
        (u'ガ',       'ga'),
        (u'ギ',       'gi'),
        (u'グ',       'gu'),
        (u'ゲ',       'ge'),
        (u'ゴ',       'go'),
        (u'サ',       'sa'),
        (u'シ',       'si'),
        (u'ス',       'su'),
        (u'セ',       'se'),
        (u'ソ',       'so'),
        (u'ザ',       'za'),
        (u'ジ',       'zi'),
        (u'ズ',       'zu'),
        (u'ゼ',       'ze'),
        (u'ゾ',       'zo'),
        (u'タ',       'ta'),
        (u'チ',       'ci'),
        (u'ツ',       'cu'),
        (u'テ',       'te'),
        (u'ト',       'to'),
        (u'ダ',       'da'),
        (u'ヂ',       'zi'),
        (u'ヅ',       'zu'),
        (u'デ',       'de'),
        (u'ド',       'do'),
        (u'ナ',       'na'),
        (u'ニ',       'ni'),
        (u'ヌ',       'nu'),
        (u'ネ',       'ne'),
        (u'ノ',       'no'),
        (u'ハ',       'ha'),
        (u'ヒ',       'hi'),
        (u'フ',       'hu'),
        (u'ヘ',       'he'),
        (u'ホ',       'ho'),
        (u'バ',       'ba'),
        (u'ビ',       'bi'),
        (u'ブ',       'bu'),
        (u'ベ',       'be'),
        (u'ボ',       'bo'),
        (u'パ',       'pa'),
        (u'ピ',       'pi'),
        (u'プ',       'pu'),
        (u'ペ',       'pe'),
        (u'ポ',       'po'),
        (u'マ',       'ma'),
        (u'ミ',       'mi'),
        (u'ム',       'mu'),
        (u'メ',       'me'),
        (u'モ',       'mo'),
        (u'ヤ',       'ya'),
        (u'ユ',       'yu'),
        (u'ヨ',       'yo'),
        (u'ャ',       'ja'),
        (u'ュ',       'ju'),
        (u'ョ',       'jo'),
        (u'ラ',       'la'),
        (u'リ',       'li'),
        (u'ル',       'lu'),
        (u'レ',       'le'),
        (u'ロ',       'lo'),
        (u'ワ',       'wa'),
        (u'ヲ',       'o'),
        (u'ン',       'N'),
        (u'ッ',       'T'),
        (u'ー',       None),
        ('^k',        'g'),
        ('^t',        'd'),
        ('^c{a|i}',   'z'),
        ('{(y|j)o}o', 'O'),
        ('{a}a',      None),
        ('{i}i',      None),
        ('{u|o}u',    None),
        ('{e}e',      None),
        ('{o}o',      None),
        ('O',         'o'),
        ('{c|z}ija',  'a'),
        ('{c|z}iju',  Jungseong(U)),
        ('{c|z}ijo',  'o'),
        ('cu',        Choseong(SS), Jungseong(EU)),
        ('wa',        Jungseong(WA)),
        ('{s|z}u',    Jungseong(EU)),
        ('k',         Choseong(K)),
        ('g',         Choseong(G)),
        ('s',         Choseong(S)),
        ('z',         Choseong(J)),
        ('t',         Choseong(T)),
        ('c',         Choseong(C)),
        ('d',         Choseong(D)),
        ('n',         Choseong(N)),
        ('h',         Choseong(H)),
        ('b',         Choseong(B)),
        ('p',         Choseong(P)),
        ('m',         Choseong(M)),
        ('l',         Choseong(L)),
        ('ya',        Jungseong(YA)),
        ('yu',        Jungseong(YU)),
        ('yo',        Jungseong(YO)),
        ('ija',       Jungseong(YA)),
        ('iju',       Jungseong(YU)),
        ('ijo',       Jungseong(YO)),
        ('a',         Jungseong(A)),
        ('i',         Jungseong(I)),
        ('u',         Jungseong(U)),
        ('e',         Jungseong(E)),
        ('o',         Jungseong(O)),
        ('N',         Jongseong(N)),
        ('T',         Jongseong(S)),
        (u'・',       ' '),
    ])

    def normalize(self, string):
        def hiragana_to_katakana(c):
            code = ord(c)
            if code not in range(0x3040, 0x309f + 1):
                return c
            return unichr(code + 96)
        return ''.join(map(hiragana_to_katakana, string))


__lang__ = Japanese
