# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Lithuanian(Language):
    """For transcribing Lithuanian."""

    __iso639__ = {1: 'lt', 2: 'lit', 3: 'lit'}
    __tmp__ = ',;%'

    vowels = u'aeiįou'
    cs = 'bcCdDfghHklmnNprsStvXzZ'
    vo = 'bdDghlmnNrvXzZ'
    vl = 'cCfHkpsSt'
    notation = Notation([
        (u'č', 'C'),
        (u'š', 'S'),
        ('{@}n{g|k}', 'N'),
        ('Ng{@|J|l|r}', 'N,g'),
        ('Ng', 'N,'),
        ('ch', 'H'),
        ('ts', 'c'),
        ('tS', 'C'),
        ('dz', 'X'),
        ('tz', 'X'),
        (u'dž', 'D'),
        (u'tž', 'D'),
        (u'ž', 'Z'),
        ('y', 'i'),
        ('ie', 'i%e'),
        ('i{@}', 'J'),
        (u'į', 'i'),
        ('{s|S}je', 'Je'),
        ('{<cs>}je', 'e'),
        ('j{@}', 'J'),
        ('j', 'i'),
        ('{c|C|D|S|X|z|Z}J', None),
        ('qu', 'kv'),
        ('q', 'k'),
        ('w', 'v'),
        ('{@}v{<cs>}', 'u'),
        ('{@}v$', 'u'),
        ('x', 'ks'),
        ('bb', 'b'),
        ('dd', 'd'),
        ('ff', 'f'),
        ('gg', 'g'),
        ('hh', 'h'),
        ('kk', 'k'),
        ('ll', 'l'),
        ('mm', 'm,m'),
        ('nn', 'n,n'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('SS', 'S'),
        ('tt', 't'),
        ('vv', 'v'),
        ('zz', 'z'),
        ('ZZ', 'Z'),
        ('ds{<vo>}', 'X'),
        ('ds', 'c'),
        ('dS{<vo>}', 'Z'),
        ('dS', 'C'),
        ('bz{<vl>}', 'ps'),
        ('gz{<vl>}', 'ks'),
        ('bZ{<vl>}', 'pS'),
        ('gZ{<vl>}', 'kS'),
        ('b{<vl>}', 'p'),
        ('b$', 'p'),
        ('d{<vl>}', 't'),
        ('d$', 't'),
        ('D{<vl>}', 'C'),
        ('D$', 'C'),
        ('g{<vl>}', 'k'),
        ('g$', 'k'),
        ('X{<vl>}', 'c'),
        ('X$', 'c'),
        ('z{<vl>}', 's'),
        ('z$', 's'),
        ('Z{<vl>}', 'S'),
        ('Z$', 'S'),
        ('{@}k{<vl>}', 'k,'),
        ('{@}p{<vl>}', 'p,'),
        ('ts', 'c'),
        ('tS', 'C'),
        ('C{<cs>}', 'ci'),
        ('C$', 'ci'),
        ('D{<cs>}', 'zi'),
        ('Z{<cs>}', 'zu'),
        ('S{<cs>}', 'sJu'),
        ('S$', 'sJu'),
        ('C', 'c'),
        ('D', 'z'),
        ('H', 'h'),
        ('S', 'sJ'),
        ('X', 'z'),
        ('Z', 'z'),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|J|m,|n,}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@|J}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('-', None),
        ('b', Choseong(B)),
        ('c', Choseong(C)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(G)),
        ('h', Choseong(H)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t', Choseong(T)),
        ('v', Choseong(B)),
        ('z', Choseong(J)),
        ('Ja', Jungseong(YA)),
        ('Je', Jungseong(YE)),
        ('Ji', Jungseong(I)),
        ('Jo', Jungseong(YO)),
        ('Ju', Jungseong(YU)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('u', Jungseong(U)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Č': u'č', u'Į': u'į', u'Í': u'į', u'í': u'į', u'Ì': u'į',
            u'ì': u'į', u'Ĩ': u'į', u'ĩ': u'į', u'Ī': u'į', u'ī': u'į',
            u'Š': u'š', u'Ž': u'ž'
        })


__lang__ = Lithuanian
