# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Russian(Language):
    """For transcribing Russian."""

    __iso639__ = {1: 'ru', 2: 'rus', 3: 'rus'}
    __tmp__ = ',;'

    vowels = u'аеёийоуыъьэюя'
    cs = u'бвгджзклмнпрстфхцчшщ'
    vl = u'кпстфхцчшщ'
    notation = Notation([
        (u'град', u'град-'),
        (u'город', u'город-'),
        (u'^ль', u'л-ь'),
        (u'{л|м|н}ь$', None),
        (u'{л|м|н}ь{<cs>}', None),
        (u'бб', u'б'),
        (u'вв', u'в'),
        (u'гг', u'г'),
        (u'дд', u'д'),
        (u'дц', u'ц'),
        (u'дч', u'ч'),
        (u'жж', u'ж'),
        (u'зз', u'з'),
        (u'кк', u'к'),
        (u'лл', u'л'),
        (u'{@}мм{@}', u'м,м'),
        (u'мм', u'м'),
        (u'{@}нн{@}', u'н,н'),
        (u'нн', u'н'),
        (u'пп', u'п'),
        (u'рр', u'р'),
        (u'сс', u'с'),
        (u'тт', u'т'),
        (u'тц', u'ц'),
        (u'тч', u'ч'),
        (u'фф', u'ф'),
        (u'хх', u'х'),
        (u'цц', u'ц'),
        (u'чч', u'ч'),
        (u'шш', u'ш'),
        (u'щщ', u'щ'),
        (u'ий', u'и'),
        (u'ый', u'ы'),
        (u'дс$', u'ц'),
        (u'дс{<cs>}', u'ц'),
        (u'тс', u'ц'),
        (u'дз', u'з'),
        (u'дж', u'ж'),
        (u'нкт', u'Nт'),
        (u'б{<vl>}', u'п'),
        (u'б$', u'п'),
        (u'в{<vl>}', u'ф'),
        (u'в$', u'ф'),
        (u'г{<vl>}', u'к'),
        (u'г$', u'к'),
        (u'д{<vl>}', u'т'),
        (u'д$', u'т'),
        (u'ж{<vl>}', u'ш'),
        (u'ж$', u'ш'),
        (u'з{<vl>}', u'с'),
        (u'з$', u'с'),
        (u'^к', u'к;'),
        (u'к{<vl>}', u'к,'),
        (u'^п', u'п;'),
        (u'п{<vl>}', u'п,'),
        (u'^т', u'т;'),
        (u'т{<vl>}', u'т,'),
        (u'^ф', u'ф;'),
        (u'ф{<vl>}', u'п,'),
        (u';', None),
        (u',к,', u',к'),
        (u',п,', u',п'),
        (u',т,', u',т'),
        (u'{ж|з|ц|ч}ё', u'о'),
        (u'{ж|з|ц|ч}ю', u'у'),
        (u'{ж|з|ц|ч}я', u'а'),
        (u'^э', u'е'),
        (u'{@|ъ|ь}э', u'е'),
        (u'щ', u'ш'),
        (u'ше', u'с-е'),
        (u'{<cs>}е', u'э'),
        (u'ша', u'ся'),
        (u'шо', u'сё'),
        (u'шу', u'сю'),
        (u'ш{и|й|ы|ъ|ь}', u'с'),
        (u'ш', u'сь'),
        (u'ч$', u'чь'),
        (u'ч{<cs>}', u'чь'),
        (u'^л', u'л;'),
        (u'^м', u'м;'),
        (u'^н', u'н;'),
        (u'л$', u'л,'),
        (u'м$', u'м,'),
        (u'н$', u'н,'),
        (u'л{@|м,|н,}', u'л;'),
        (u'м{@|л}', u'м;'),
        (u'н{@|л}', u'н;'),
        (u'л', u'л,'),
        (u'м', u'м,'),
        (u'н', u'н,'),
        (u',,', u','),
        (u',;', None),
        (u',л,', u'л,'),
        (u',м,', u'м,'),
        (u',н,', u'н,'),
        (u'л{м;|н;}', u'л,'),
        (u';|-', None),
        (u'б', Choseong(B)),
        (u'в', Choseong(B)),
        (u'г', Choseong(G)),
        (u'д', Choseong(D)),
        (u'ж', Choseong(J)),
        (u'з', Choseong(J)),
        (u'ж', Choseong(J)),
        (u'к,', Jongseong(G)),
        (u'к', Choseong(K)),
        (u'^л', Choseong(L)),
        (u'л,', Jongseong(L)),
        (u'л', Jongseong(L), Choseong(L)),
        (u'м,', Jongseong(M)),
        (u'м', Choseong(M)),
        (u'н,', Jongseong(N)),
        (u'н', Choseong(N)),
        (u'N', Jongseong(NG)),
        (u'п,', Jongseong(B)),
        (u'п', Choseong(P)),
        (u'р', Choseong(L)),
        (u'с', Choseong(S)),
        (u'т,', Jongseong(S)),
        (u'т', Choseong(T)),
        (u'ф', Choseong(P)),
        (u'х', Choseong(H)),
        (u'ц', Choseong(C)),
        (u'ч', Choseong(C)),
        (u'а', Jungseong(A)),
        (u'е', Jungseong(YE)),
        (u'ё', Jungseong(YO)),
        (u'и', Jungseong(I)),
        (u'й', Jungseong(I)),
        (u'о', Jungseong(O)),
        (u'у', Jungseong(U)),
        (u'ы', Jungseong(I)),
        (u'ъ', Jungseong(I)),
        (u'ь', Jungseong(I)),
        (u'э', Jungseong(E)),
        (u'ю', Jungseong(YU)),
        (u'я', Jungseong(YA)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'А': u'а', u'Б': u'б', u'В': u'в', u'Г': u'г', u'Д': u'д',
            u'Е': u'е', u'Ё': u'ё', u'Ж': u'ж', u'З': u'з', u'И': u'и',
            u'Й': u'й', u'К': u'к', u'Л': u'л', u'М': u'м', u'Н': u'н',
            u'О': u'о', u'П': u'п', u'Р': u'р', u'С': u'с', u'Т': u'т',
            u'У': u'у', u'Ф': u'ф', u'Х': u'х', u'Ц': u'ц', u'Ч': u'ч',
            u'Ш': u'ш', u'Щ': u'щ', u'Ъ': u'ъ', u'Ы': u'ы', u'Ь': u'ь',
            u'Э': u'э', u'Ю': u'ю', u'Я': u'я'
        })


__lang__ = Russian
