# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Turkish(Language):
    """For transcribing Turkish."""

    __iso639__ = {1: 'tr', 2: 'tur', 3: 'tur'}
    __tmp__ = ',;G'

    vowels = 'aeIioOuU'
    cs = 'bcCdfgGhjklmnNprsStvz'
    vl = 'CfhkpsSt'
    notation = Notation([
        (u'ç', 'C'),
        (u'ğ', 'G'),
        (u'ı', 'I'),
        (u'ö', 'O'),
        (u'ş', 'S'),
        (u'ü', 'U'),
        ('^y{@}', 'Y'),
        ('iyy', 'iy'),
        ('yy', 'iy'),
        ('{@}y{@}', 'Y'),
        ('iy', 'i'),
        ('y', 'i'),
        ('rl', 'l'),
        ('{p|t|k}h', None),
        ('q', 'k'),
        ('w', 'v'),
        ('x', 'h'),
        ('bb', 'b'),
        ('cc', 'c'),
        ('CC', 'C'),
        ('dd', 'd'),
        ('dc', 'c'),
        ('ff', 'f'),
        ('gg', 'g'),
        ('GG', 'G'),
        ('hh', 'h'),
        ('jj', 'j'),
        ('kk', 'k'),
        ('ll', 'l'),
        ('mm', 'm,m'),
        ('nn', 'n,n'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('SS', 'S'),
        ('tt', 't'),
        ('tC', 'C'),
        ('vv', 'v'),
        ('zz', 'z'),
        ('{@}g{<vl>}', 'k,'),
        ('{@}k{<vl>}', 'k,'),
        ('{@}b{<vl>}', 'p,'),
        ('{@}p{<vl>}', 'p,'),
        ('c{<cs>}', 'ci'),
        ('c$', 'ci'),
        ('C{<cs>}', 'Ci'),
        ('C$', 'Ci'),
        ('j{<cs>}', 'ju'),
        ('j$', 'ju'),
        ('S{@}', 'sY'),
        ('S', 'sYu'),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('{@}n{g|k}$', 'N'),
        ('{@}n{g<cs>|k<cs>}', 'N'),
        ('ng{@}', 'Ng'),
        ('nk{@}', 'Nk'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('b', Choseong(B)),
        ('c', Choseong(J)),
        ('C', Choseong(C)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(G)),
        ('h', Choseong(H)),
        ('j', Choseong(J)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t', Choseong(T)),
        ('v', Choseong(B)),
        ('z', Choseong(J)),
        ('Ya', Jungseong(YA)),
        ('Ye', Jungseong(YE)),
        ('YI', Jungseong(I), Jungseong(EU)),
        ('Yi', Jungseong(I)),
        ('Yo', Jungseong(YO)),
        ('YO', Jungseong(OE)),
        ('Yu', Jungseong(YU)),
        ('YU', Jungseong(WI)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('I', Jungseong(EU)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('O', Jungseong(OE)),
        ('u', Jungseong(U)),
        ('U', Jungseong(WI)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ç': u'ç', u'Ğ': u'ğ', u'I': u'ı', u'İ': u'i', u'Ö': u'ö',
            u'Ş': u'ş', u'Ü': u'ü'
        })


__lang__ = Turkish
